import { SortType, CheckboxState, CheckboxOnChange } from '../helpers/types';
/**
 * This is an interface for customizing the classes for
 * the `TableHeaderClasses` component.
 */
export interface TableHeaderClasses {
    /** The class for the `thead` tag. */
    thead?: string;
    /** The class for the `tr` tags inside `tbody`. */
    tr?: string;
    /** The class for the `th` tags inside each `tr` tag. */
    th?: string;
}
/**
 * This is an interface for `TableHeader` component props.
 */
export interface TableHeaderProps {
    /** Customize the classes of the `TableHeader` component. */
    classes?: TableHeaderClasses;
    /** Props to make the component controlled. */
    controlledProps?: {
        /** The function fired when the table sort state changes. */
        onSortChange?: (nextSort: SortType) => void;
        /** The current sort state of the table. */
        sortState?: SortType;
        /** The function fired when any checkbox in the table changes. */
        onCheckboxChange?: CheckboxOnChange;
        /**
         * The filtered data length. When not using filter control,
         * then this should equal to the table body's length.
         */
        filteredDataLength?: number;
        /**
         * A record, which key is the column prop name and the value
         * is of type `CheckboxState`.
         */
        checkboxState?: Record<string, CheckboxState>;
    };
}
/**
 * Renders a list of table headers.
 */
export declare function TableHeader({ classes, controlledProps }: TableHeaderProps): JSX.Element;
